[−][src]Struct libaster::protocol::CmdFlags
Methods
impl CmdFlags[src]
pub const DONE: CmdFlags[src]
pub const ASK: CmdFlags[src]
pub const MOVED: CmdFlags[src]
pub const NOREPLY: CmdFlags[src]
pub const QUIET: CmdFlags[src]
pub const ERROR: CmdFlags[src]
pub const fn empty() -> CmdFlags[src]
Returns an empty set of flags
pub const fn all() -> CmdFlags[src]
Returns the set containing all flags.
pub const fn bits(&self) -> u8[src]
Returns the raw value of the flags currently stored.
pub fn from_bits(bits: u8) -> Option<CmdFlags>[src]
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub const fn from_bits_truncate(bits: u8) -> CmdFlags[src]
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
pub const unsafe fn from_bits_unchecked(bits: u8) -> CmdFlags[src]
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
pub const fn is_empty(&self) -> bool[src]
Returns true if no flags are currently stored.
pub const fn is_all(&self) -> bool[src]
Returns true if all flags are currently set.
pub const fn intersects(&self, other: CmdFlags) -> bool[src]
Returns true if there are flags common to both self and other.
pub const fn contains(&self, other: CmdFlags) -> bool[src]
Returns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: CmdFlags)[src]
Inserts the specified flags in-place.
pub fn remove(&mut self, other: CmdFlags)[src]
Removes the specified flags in-place.
pub fn toggle(&mut self, other: CmdFlags)[src]
Toggles the specified flags in-place.
pub fn set(&mut self, other: CmdFlags, value: bool)[src]
Inserts or removes the specified flags depending on the passed value.